@@ -7,7 +7,7 @@
 #include <QtSensors/QSensorBackend>
 #include <QtCore/QScopedPointer>
 
-QT_USE_NAMESPACE
+QT_BEGIN_NAMESPACE
 
 class WinRtGyroscopePrivate;
 class WinRtGyroscope : public QSensorBackend
@@ -32,4 +32,6 @@ private:
     Q_DECLARE_PRIVATE(WinRtGyroscope)
 };
 
+QT_END_NAMESPACE
+
 #endif // WINRTGYROSCOPE_H
