@@ -7,7 +7,7 @@
 #include <QtSensors/QSensorBackend>
 #include <QtCore/QScopedPointer>
 
-QT_USE_NAMESPACE
+QT_BEGIN_NAMESPACE
 
 class WinRtRotationSensorPrivate;
 class WinRtRotationSensor : public QSensorBackend
@@ -32,4 +32,6 @@ private:
     Q_DECLARE_PRIVATE(WinRtRotationSensor)
 };
 
+QT_END_NAMESPACE
+
 #endif // WINRTROTATIONSENSOR_H
